@@ -37,6 +37,8 @@
 #define STK_ARRAY2DNUMBER_H
 
 #include "STK_IArray2D.h"
+#include "STK_IArray2DSlicers.h"
+#include "STK_IArray2DModifiers.h"
 
 namespace STK
 {
@@ -68,7 +70,7 @@ struct Traits< Array2DNumber<Type_> >
   typedef Array2DNumber<Type_>  SubVector;
 
   typedef Type_                Type;
-  typedef typename RemoveConst<Type>::Type const& ConstReturnType;
+  typedef typename RemoveConst<Type>::Type const& TypeConst;
 
   enum
   {
@@ -76,8 +78,11 @@ struct Traits< Array2DNumber<Type_> >
     orient_    = Arrays::by_col_,
     sizeRows_  = 1,
     sizeCols_  = 1,
+    size_      = 1,
     storage_   = Arrays::dense_ // always dense
   };
+  typedef Array1D<Type, UnknownSize> ColVector;
+  typedef ColVector* PtrCol;
 };
 
 } // namespace hidden
@@ -98,23 +103,24 @@ class Array2DNumber: public IArray2D< Array2DNumber<Type_> >
     typedef IArray2D< Array2DNumber<Type_> > Base;
     typedef ArrayBase< Array2DNumber<Type_> > LowBase;
 
-    typedef typename hidden::Traits<Array2DNumber<Type_> >::Row Row;
-    typedef typename hidden::Traits<Array2DNumber<Type_> >::Col Col;
-    typedef typename hidden::Traits<Array2DNumber<Type_> >::SubRow SubRow;
-    typedef typename hidden::Traits<Array2DNumber<Type_> >::SubCol SubCol;
-    typedef typename hidden::Traits<Array2DNumber<Type_> >::SubVector SubVector;
-    typedef typename hidden::Traits<Array2DNumber<Type_> >::SubArray SubArray;
+    typedef typename hidden::Traits< Array2DNumber<Type_> >::Row Row;
+    typedef typename hidden::Traits< Array2DNumber<Type_> >::Col Col;
+    typedef typename hidden::Traits< Array2DNumber<Type_> >::SubRow SubRow;
+    typedef typename hidden::Traits< Array2DNumber<Type_> >::SubCol SubCol;
+    typedef typename hidden::Traits< Array2DNumber<Type_> >::SubVector SubVector;
+    typedef typename hidden::Traits< Array2DNumber<Type_> >::SubArray SubArray;
 
-    typedef typename hidden::Traits<Array2DNumber<Type_> >::Type Type;
-    typedef typename hidden::Traits<Array2DNumber<Type_> >::ConstReturnType ConstReturnType;
+    typedef typename hidden::Traits< Array2DNumber<Type_> >::Type Type;
+    typedef typename hidden::Traits< Array2DNumber<Type_> >::TypeConst TypeConst;
 
-   enum
+    enum
     {
-      structure_ = hidden::Traits<Array2DNumber>::structure_,
-      orient_    = hidden::Traits<Array2DNumber>::orient_,
-      sizeRows_  = hidden::Traits<Array2DNumber>::sizeRows_,
-      sizeCols_  = hidden::Traits<Array2DNumber>::sizeCols_,
-      storage_   = hidden::Traits<Array2DNumber>::storage_
+       structure_ = hidden::Traits< Array2DNumber >::structure_,
+       orient_    = hidden::Traits< Array2DNumber >::orient_,
+       sizeRows_  = hidden::Traits< Array2DNumber >::sizeRows_,
+       sizeCols_  = hidden::Traits< Array2DNumber >::sizeCols_,
+       size_      = hidden::Traits< Array2DNumber >::size_,
+       storage_   = hidden::Traits< Array2DNumber >::storage_
     };
 
     /** Default constructor */
@@ -152,12 +158,12 @@ class Array2DNumber: public IArray2D< Array2DNumber<Type_> >
                  : Base(p_data, Range(row, 1), Range(col, 1)) {}
     /** destructor. */
     ~Array2DNumber() {}
-    /** @return a constant reference on the jth element
-     **/
-    inline Type const& elt0Impl() const { return this->data(this->beginCols())[this->beginRows()];}
-    /** @return a reference on the jth element
-     **/
-    inline Type& elt0Impl() { return this->data(this->beginCols())[this->beginRows()];}
+    /** @return a constant reference to element */
+    inline Type const& elt0Impl() const
+    { return (this->allocator_.elt(this->beginCols()))->elt(this->beginRows());}
+    /** @return a reference on to the element */
+    inline Type& elt0Impl()
+    { return (this->allocator_.elt(this->beginCols()))->elt(this->beginRows());}
     /** New first indexes for the object.
      *  @param cbeg the index of the first column to set
      **/
