@@ -56,30 +56,59 @@ class Polynomial: public IKernelBase<Array>
 {
   public:
     typedef IKernelBase<Array> Base;
-    typedef typename Array::Row RowVector;
+    typedef typename Array::Type Type;
     using Base::p_data_;
     using Base::gram_;
-    using Base::symmetrize;
+    using Base::hasRun_;
+
+    /** Default constructor with the degree and the shift
+     *  @param d degree of the polynomial
+     *  @param shift the shift to use in the kernel
+     **/
+    Polynomial( Real const& d=2., Real const& shift= 0)
+             : Base(0), d_(d), shift_(shift)
+    {}
     /** constructor with a constant pointer on the data set
      *  @param p_data a pointer on a data set that will be "kernelized"
-     *  @param shift the shift to use in the kernel
      *  @param d degree of the polynomial
+     *  @param shift the shift to use in the kernel
      **/
     Polynomial( Array const* p_data, Real const& d=2., Real const& shift= 0)
-              : Base(p_data), d_(d), shift_(shift)
+             : Base(p_data), d_(d), shift_(shift)
     { if (d_ <= 0.)
       STKDOMAIN_ERROR_2ARG(Polynomial::Polynomial,shift,d,d must be>0);
     }
     /** constructor with a constant reference on the data set
      *  @param data a reference on a data set that will be "kernelized"
-     *  @param shift the shift to use in the kernel
      *  @param d degree of the polynomial
+     *  @param shift the shift to use in the kernel
      **/
     Polynomial( Array const& data, Real const& d=2., Real const& shift= 0.)
-              : Base(data), d_(d), shift_(shift)
+             : Base(data), d_(d), shift_(shift)
     { if (d_ <= 0.)
       STKDOMAIN_ERROR_2ARG(Polynomial::Polynomial,shift,d,d must be>0);
     }
+    /** constructor with an array of parameter.
+     *  @param p_data a pointer on a data set that will be "kernelized"
+     *  @param param array of parameter
+     **/
+    template<class Derived>
+    Polynomial( Array const* p_data, ExprBase<Derived> const& param)
+             : Base(p_data)
+              , d_(param.empty() ? 2. : param.front())
+              , shift_(param.empty() ? 2. : param.elt(param.begin()+1))
+    {}
+    /** constructor with a constant pointer on the data set
+     *  @param data a reference on a data set that will be "kernelized"
+     *  @param param array of parameter
+     **/
+    template<class Derived>
+    Polynomial( Array const& data, ExprBase<Derived> const& param)
+             : Base(data)
+              , d_(param.empty() ? 2. : param.front())
+              , shift_(param.empty() ? 2. : param.elt(param.begin()+1))
+    {}
+
     /** destructor */
     virtual ~Polynomial() {}
     /** @return the degree of the kernel */
@@ -90,14 +119,25 @@ class Polynomial: public IKernelBase<Array>
     Real const& shift() const {return shift_;}
     /** set the shift of the kernel */
     void setShift(Real const& shift) { shift_ = shift;}
-
-    /** compute the kernel value between two individuals
-     *  @param ind1,ind2 two individuals to compare using the kernel metric */
-    virtual Real kcomp(RowVector const& ind1, RowVector const& ind2) const;
-    /** compute the kernel between an individual and himself
-     *  @param ind the individual to evaluate using the kernel
+    /** Set parameter using an array
+     *  @param param array of parameter
      **/
-    virtual Real kdiag(RowVector const& ind) const;
+    template<class Derived>
+    void setParam(  ExprBase<Derived> const& param)
+    { d_ = (param.empty() ? 2. : param.front());
+      shift_ = (param.empty() ? 0. : param.elt(param.begin()+1));
+    }
+
+    /** virtual method.
+     *  @return diagonal value of the kernel for the ith individuals.
+     *  @param i index of the individual
+     **/
+    virtual Real diag(int i) const;
+    /** virtual method implementation.
+     *  @return value of the kernel for the ith and jth individuals.
+     *  @param i,j indexes of the individuals
+     **/
+    virtual Real comp(int i, int j) const;
 
   private:
     /** degree of the kernel */
@@ -106,13 +146,21 @@ class Polynomial: public IKernelBase<Array>
     Real shift_;
 };
 
+/* virtual method.
+ *  @return diagonal value of the kernel for the ith individuals.
+ *  @param i index of the individual
+ **/
 template<class Array>
-Real Polynomial<Array>::kcomp(RowVector const& ind1, RowVector const& ind2) const
-{ return std::pow(ind1.dot(ind2) + shift_, d_);}
+inline Real Polynomial<Array>::diag(int i) const
+{ return hasRun_ ? gram_(i,i)
+                 :  std::pow(p_data_->row(i).norm2() + shift_, d_);
+}
 
 template<class Array>
-Real Polynomial<Array>::kdiag(RowVector const& ind) const
-{ return std::pow(ind.norm2() + shift_, d_);}
+inline Real Polynomial<Array>::comp(int i, int j) const
+{ return hasRun_ ? gram_(i,j)
+                 :  std::pow(p_data_->row(i).dot(p_data_->row(j)) + shift_, d_);}
+
 
 } // namespace Kernel
 
