@@ -35,8 +35,9 @@
 #ifndef STK_STAT_MULTIVARIATE_H
 #define STK_STAT_MULTIVARIATE_H
 
+#include <Sdk.h>
+
 #include "Arrays/include/STK_Array2DVector.h"
-#include "Sdk/include/STK_IRunner.h"
 
 namespace STK
 {
@@ -50,7 +51,7 @@ namespace Stat
  *  ITContainer and contain elements of type Type.
  **/
 template < class Array, class WColVector, typename Type =  typename Array::Type >
-class Multivariate : public IRunnerUnsupervised< Array, WColVector>
+class Multivariate: public IRunnerUnsupervised< Array, WColVector>
 {
   public:
     typedef IRunnerUnsupervised< Array, WColVector> Runner2D;
